# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountSettingV2Result',
    'AwaitableGetAccountSettingV2Result',
    'get_account_setting_v2',
    'get_account_setting_v2_output',
]

@pulumi.output_type
class GetAccountSettingV2Result:
    """
    A collection of values returned by getAccountSettingV2.
    """
    def __init__(__self__, aibi_dashboard_embedding_access_policy=None, aibi_dashboard_embedding_approved_domains=None, automatic_cluster_update_workspace=None, boolean_val=None, effective_aibi_dashboard_embedding_access_policy=None, effective_aibi_dashboard_embedding_approved_domains=None, effective_automatic_cluster_update_workspace=None, effective_boolean_val=None, effective_integer_val=None, effective_personal_compute=None, effective_restrict_workspace_admins=None, effective_string_val=None, id=None, integer_val=None, name=None, personal_compute=None, restrict_workspace_admins=None, string_val=None):
        if aibi_dashboard_embedding_access_policy and not isinstance(aibi_dashboard_embedding_access_policy, dict):
            raise TypeError("Expected argument 'aibi_dashboard_embedding_access_policy' to be a dict")
        pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains and not isinstance(aibi_dashboard_embedding_approved_domains, dict):
            raise TypeError("Expected argument 'aibi_dashboard_embedding_approved_domains' to be a dict")
        pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace and not isinstance(automatic_cluster_update_workspace, dict):
            raise TypeError("Expected argument 'automatic_cluster_update_workspace' to be a dict")
        pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val and not isinstance(boolean_val, dict):
            raise TypeError("Expected argument 'boolean_val' to be a dict")
        pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy and not isinstance(effective_aibi_dashboard_embedding_access_policy, dict):
            raise TypeError("Expected argument 'effective_aibi_dashboard_embedding_access_policy' to be a dict")
        pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains and not isinstance(effective_aibi_dashboard_embedding_approved_domains, dict):
            raise TypeError("Expected argument 'effective_aibi_dashboard_embedding_approved_domains' to be a dict")
        pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace and not isinstance(effective_automatic_cluster_update_workspace, dict):
            raise TypeError("Expected argument 'effective_automatic_cluster_update_workspace' to be a dict")
        pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_boolean_val and not isinstance(effective_boolean_val, dict):
            raise TypeError("Expected argument 'effective_boolean_val' to be a dict")
        pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_integer_val and not isinstance(effective_integer_val, dict):
            raise TypeError("Expected argument 'effective_integer_val' to be a dict")
        pulumi.set(__self__, "effective_integer_val", effective_integer_val)
        if effective_personal_compute and not isinstance(effective_personal_compute, dict):
            raise TypeError("Expected argument 'effective_personal_compute' to be a dict")
        pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins and not isinstance(effective_restrict_workspace_admins, dict):
            raise TypeError("Expected argument 'effective_restrict_workspace_admins' to be a dict")
        pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if effective_string_val and not isinstance(effective_string_val, dict):
            raise TypeError("Expected argument 'effective_string_val' to be a dict")
        pulumi.set(__self__, "effective_string_val", effective_string_val)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if integer_val and not isinstance(integer_val, dict):
            raise TypeError("Expected argument 'integer_val' to be a dict")
        pulumi.set(__self__, "integer_val", integer_val)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if personal_compute and not isinstance(personal_compute, dict):
            raise TypeError("Expected argument 'personal_compute' to be a dict")
        pulumi.set(__self__, "personal_compute", personal_compute)
        if restrict_workspace_admins and not isinstance(restrict_workspace_admins, dict):
            raise TypeError("Expected argument 'restrict_workspace_admins' to be a dict")
        pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val and not isinstance(string_val, dict):
            raise TypeError("Expected argument 'string_val' to be a dict")
        pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> 'outputs.GetAccountSettingV2AibiDashboardEmbeddingAccessPolicyResult':
        """
        (AibiDashboardEmbeddingAccessPolicy)
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> 'outputs.GetAccountSettingV2AibiDashboardEmbeddingApprovedDomainsResult':
        """
        (AibiDashboardEmbeddingApprovedDomains)
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> 'outputs.GetAccountSettingV2AutomaticClusterUpdateWorkspaceResult':
        """
        (ClusterAutoRestartMessage)
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> 'outputs.GetAccountSettingV2BooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> 'outputs.GetAccountSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyResult':
        """
        (AibiDashboardEmbeddingAccessPolicy)
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> 'outputs.GetAccountSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsResult':
        """
        (AibiDashboardEmbeddingApprovedDomains)
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> 'outputs.GetAccountSettingV2EffectiveAutomaticClusterUpdateWorkspaceResult':
        """
        (ClusterAutoRestartMessage)
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> 'outputs.GetAccountSettingV2EffectiveBooleanValResult':
        """
        (BooleanMessage)
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> 'outputs.GetAccountSettingV2EffectiveIntegerValResult':
        """
        (IntegerMessage)
        """
        return pulumi.get(self, "effective_integer_val")

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> 'outputs.GetAccountSettingV2EffectivePersonalComputeResult':
        """
        (PersonalComputeMessage)
        """
        return pulumi.get(self, "effective_personal_compute")

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> 'outputs.GetAccountSettingV2EffectiveRestrictWorkspaceAdminsResult':
        """
        (RestrictWorkspaceAdminsMessage)
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> 'outputs.GetAccountSettingV2EffectiveStringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> 'outputs.GetAccountSettingV2IntegerValResult':
        """
        (IntegerMessage)
        """
        return pulumi.get(self, "integer_val")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> 'outputs.GetAccountSettingV2PersonalComputeResult':
        """
        (PersonalComputeMessage)
        """
        return pulumi.get(self, "personal_compute")

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> 'outputs.GetAccountSettingV2RestrictWorkspaceAdminsResult':
        """
        (RestrictWorkspaceAdminsMessage)
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> 'outputs.GetAccountSettingV2StringValResult':
        """
        (StringMessage)
        """
        return pulumi.get(self, "string_val")


class AwaitableGetAccountSettingV2Result(GetAccountSettingV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountSettingV2Result(
            aibi_dashboard_embedding_access_policy=self.aibi_dashboard_embedding_access_policy,
            aibi_dashboard_embedding_approved_domains=self.aibi_dashboard_embedding_approved_domains,
            automatic_cluster_update_workspace=self.automatic_cluster_update_workspace,
            boolean_val=self.boolean_val,
            effective_aibi_dashboard_embedding_access_policy=self.effective_aibi_dashboard_embedding_access_policy,
            effective_aibi_dashboard_embedding_approved_domains=self.effective_aibi_dashboard_embedding_approved_domains,
            effective_automatic_cluster_update_workspace=self.effective_automatic_cluster_update_workspace,
            effective_boolean_val=self.effective_boolean_val,
            effective_integer_val=self.effective_integer_val,
            effective_personal_compute=self.effective_personal_compute,
            effective_restrict_workspace_admins=self.effective_restrict_workspace_admins,
            effective_string_val=self.effective_string_val,
            id=self.id,
            integer_val=self.integer_val,
            name=self.name,
            personal_compute=self.personal_compute,
            restrict_workspace_admins=self.restrict_workspace_admins,
            string_val=self.string_val)


def get_account_setting_v2(name: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountSettingV2Result:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account setting.

    ## Example Usage

    Referring to a setting by id


    :param _builtins.str name: Name of the setting
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAccountSettingV2:getAccountSettingV2', __args__, opts=opts, typ=GetAccountSettingV2Result).value

    return AwaitableGetAccountSettingV2Result(
        aibi_dashboard_embedding_access_policy=pulumi.get(__ret__, 'aibi_dashboard_embedding_access_policy'),
        aibi_dashboard_embedding_approved_domains=pulumi.get(__ret__, 'aibi_dashboard_embedding_approved_domains'),
        automatic_cluster_update_workspace=pulumi.get(__ret__, 'automatic_cluster_update_workspace'),
        boolean_val=pulumi.get(__ret__, 'boolean_val'),
        effective_aibi_dashboard_embedding_access_policy=pulumi.get(__ret__, 'effective_aibi_dashboard_embedding_access_policy'),
        effective_aibi_dashboard_embedding_approved_domains=pulumi.get(__ret__, 'effective_aibi_dashboard_embedding_approved_domains'),
        effective_automatic_cluster_update_workspace=pulumi.get(__ret__, 'effective_automatic_cluster_update_workspace'),
        effective_boolean_val=pulumi.get(__ret__, 'effective_boolean_val'),
        effective_integer_val=pulumi.get(__ret__, 'effective_integer_val'),
        effective_personal_compute=pulumi.get(__ret__, 'effective_personal_compute'),
        effective_restrict_workspace_admins=pulumi.get(__ret__, 'effective_restrict_workspace_admins'),
        effective_string_val=pulumi.get(__ret__, 'effective_string_val'),
        id=pulumi.get(__ret__, 'id'),
        integer_val=pulumi.get(__ret__, 'integer_val'),
        name=pulumi.get(__ret__, 'name'),
        personal_compute=pulumi.get(__ret__, 'personal_compute'),
        restrict_workspace_admins=pulumi.get(__ret__, 'restrict_workspace_admins'),
        string_val=pulumi.get(__ret__, 'string_val'))
def get_account_setting_v2_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountSettingV2Result]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single account setting.

    ## Example Usage

    Referring to a setting by id


    :param _builtins.str name: Name of the setting
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAccountSettingV2:getAccountSettingV2', __args__, opts=opts, typ=GetAccountSettingV2Result)
    return __ret__.apply(lambda __response__: GetAccountSettingV2Result(
        aibi_dashboard_embedding_access_policy=pulumi.get(__response__, 'aibi_dashboard_embedding_access_policy'),
        aibi_dashboard_embedding_approved_domains=pulumi.get(__response__, 'aibi_dashboard_embedding_approved_domains'),
        automatic_cluster_update_workspace=pulumi.get(__response__, 'automatic_cluster_update_workspace'),
        boolean_val=pulumi.get(__response__, 'boolean_val'),
        effective_aibi_dashboard_embedding_access_policy=pulumi.get(__response__, 'effective_aibi_dashboard_embedding_access_policy'),
        effective_aibi_dashboard_embedding_approved_domains=pulumi.get(__response__, 'effective_aibi_dashboard_embedding_approved_domains'),
        effective_automatic_cluster_update_workspace=pulumi.get(__response__, 'effective_automatic_cluster_update_workspace'),
        effective_boolean_val=pulumi.get(__response__, 'effective_boolean_val'),
        effective_integer_val=pulumi.get(__response__, 'effective_integer_val'),
        effective_personal_compute=pulumi.get(__response__, 'effective_personal_compute'),
        effective_restrict_workspace_admins=pulumi.get(__response__, 'effective_restrict_workspace_admins'),
        effective_string_val=pulumi.get(__response__, 'effective_string_val'),
        id=pulumi.get(__response__, 'id'),
        integer_val=pulumi.get(__response__, 'integer_val'),
        name=pulumi.get(__response__, 'name'),
        personal_compute=pulumi.get(__response__, 'personal_compute'),
        restrict_workspace_admins=pulumi.get(__response__, 'restrict_workspace_admins'),
        string_val=pulumi.get(__response__, 'string_val')))
