# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeatureEngineeringMaterializedFeaturesResult',
    'AwaitableGetFeatureEngineeringMaterializedFeaturesResult',
    'get_feature_engineering_materialized_features',
    'get_feature_engineering_materialized_features_output',
]

@pulumi.output_type
class GetFeatureEngineeringMaterializedFeaturesResult:
    """
    A collection of values returned by getFeatureEngineeringMaterializedFeatures.
    """
    def __init__(__self__, feature_name=None, id=None, materialized_features=None, page_size=None):
        if feature_name and not isinstance(feature_name, str):
            raise TypeError("Expected argument 'feature_name' to be a str")
        pulumi.set(__self__, "feature_name", feature_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if materialized_features and not isinstance(materialized_features, list):
            raise TypeError("Expected argument 'materialized_features' to be a list")
        pulumi.set(__self__, "materialized_features", materialized_features)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> Optional[_builtins.str]:
        """
        (string) - The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="materializedFeatures")
    def materialized_features(self) -> Sequence['outputs.GetFeatureEngineeringMaterializedFeaturesMaterializedFeatureResult']:
        return pulumi.get(self, "materialized_features")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")


class AwaitableGetFeatureEngineeringMaterializedFeaturesResult(GetFeatureEngineeringMaterializedFeaturesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringMaterializedFeaturesResult(
            feature_name=self.feature_name,
            id=self.id,
            materialized_features=self.materialized_features,
            page_size=self.page_size)


def get_feature_engineering_materialized_features(feature_name: Optional[_builtins.str] = None,
                                                  page_size: Optional[_builtins.int] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringMaterializedFeaturesResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str feature_name: Filter by feature name. If specified, only materialized features materialized from this feature will be returned
    :param _builtins.int page_size: The maximum number of results to return. Defaults to 100 if not specified. Cannot be greater than 1000
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringMaterializedFeatures:getFeatureEngineeringMaterializedFeatures', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeaturesResult).value

    return AwaitableGetFeatureEngineeringMaterializedFeaturesResult(
        feature_name=pulumi.get(__ret__, 'feature_name'),
        id=pulumi.get(__ret__, 'id'),
        materialized_features=pulumi.get(__ret__, 'materialized_features'),
        page_size=pulumi.get(__ret__, 'page_size'))
def get_feature_engineering_materialized_features_output(feature_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                         page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringMaterializedFeaturesResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str feature_name: Filter by feature name. If specified, only materialized features materialized from this feature will be returned
    :param _builtins.int page_size: The maximum number of results to return. Defaults to 100 if not specified. Cannot be greater than 1000
    """
    __args__ = dict()
    __args__['featureName'] = feature_name
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringMaterializedFeatures:getFeatureEngineeringMaterializedFeatures', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeaturesResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringMaterializedFeaturesResult(
        feature_name=pulumi.get(__response__, 'feature_name'),
        id=pulumi.get(__response__, 'id'),
        materialized_features=pulumi.get(__response__, 'materialized_features'),
        page_size=pulumi.get(__response__, 'page_size')))
