# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accountId: Optional[str]

actionsIdTokenRequestToken: Optional[str]

actionsIdTokenRequestUrl: Optional[str]

audience: Optional[str]

authType: Optional[str]

azureClientId: Optional[str]

azureClientSecret: Optional[str]

azureEnvironment: Optional[str]

azureLoginAppId: Optional[str]

azureTenantId: Optional[str]

azureUseMsi: Optional[bool]

azureWorkspaceResourceId: Optional[str]

clientId: Optional[str]

clientSecret: Optional[str]

clusterId: Optional[str]

configFile: Optional[str]

databricksCliPath: Optional[str]

databricksIdTokenFilepath: Optional[str]

debugHeaders: Optional[bool]

debugTruncateBytes: Optional[int]

experimentalIsUnifiedHost: Optional[bool]

googleCredentials: Optional[str]

googleServiceAccount: Optional[str]

host: Optional[str]

httpTimeoutSeconds: Optional[int]

metadataServiceUrl: Optional[str]

oauthCallbackPort: Optional[int]

oidcTokenEnv: Optional[str]

password: Optional[str]

profile: Optional[str]

rateLimit: Optional[int]

retryTimeoutSeconds: Optional[int]

serverlessComputeId: Optional[str]

skipVerify: Optional[bool]

token: Optional[str]

username: Optional[str]

warehouseId: Optional[str]

workspaceId: Optional[str]

