# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetRfaAccessRequestDestinationsResult',
    'AwaitableGetRfaAccessRequestDestinationsResult',
    'get_rfa_access_request_destinations',
    'get_rfa_access_request_destinations_output',
]

@pulumi.output_type
class GetRfaAccessRequestDestinationsResult:
    """
    A collection of values returned by getRfaAccessRequestDestinations.
    """
    def __init__(__self__, are_any_destinations_hidden=None, destinations=None, id=None, securable=None):
        if are_any_destinations_hidden and not isinstance(are_any_destinations_hidden, bool):
            raise TypeError("Expected argument 'are_any_destinations_hidden' to be a bool")
        pulumi.set(__self__, "are_any_destinations_hidden", are_any_destinations_hidden)
        if destinations and not isinstance(destinations, list):
            raise TypeError("Expected argument 'destinations' to be a list")
        pulumi.set(__self__, "destinations", destinations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if securable and not isinstance(securable, dict):
            raise TypeError("Expected argument 'securable' to be a dict")
        pulumi.set(__self__, "securable", securable)

    @_builtins.property
    @pulumi.getter(name="areAnyDestinationsHidden")
    def are_any_destinations_hidden(self) -> _builtins.bool:
        """
        (boolean) - Indicates whether any destinations are hidden from the caller due to a lack of permissions.
        This value is true if the caller does not have permission to see all destinations
        """
        return pulumi.get(self, "are_any_destinations_hidden")

    @_builtins.property
    @pulumi.getter
    def destinations(self) -> Sequence['outputs.GetRfaAccessRequestDestinationsDestinationResult']:
        """
        (list of NotificationDestination) - The access request destinations for the securable
        """
        return pulumi.get(self, "destinations")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def securable(self) -> 'outputs.GetRfaAccessRequestDestinationsSecurableResult':
        """
        (Securable) - The securable for which the access request destinations are being retrieved
        """
        return pulumi.get(self, "securable")


class AwaitableGetRfaAccessRequestDestinationsResult(GetRfaAccessRequestDestinationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRfaAccessRequestDestinationsResult(
            are_any_destinations_hidden=self.are_any_destinations_hidden,
            destinations=self.destinations,
            id=self.id,
            securable=self.securable)


def get_rfa_access_request_destinations(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRfaAccessRequestDestinationsResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get the Request for Access (RFA) access request destinations for a specific securable object.

    ## Example Usage

    Referring to RFA access request destinations by securable type and full name:
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getRfaAccessRequestDestinations:getRfaAccessRequestDestinations', __args__, opts=opts, typ=GetRfaAccessRequestDestinationsResult).value

    return AwaitableGetRfaAccessRequestDestinationsResult(
        are_any_destinations_hidden=pulumi.get(__ret__, 'are_any_destinations_hidden'),
        destinations=pulumi.get(__ret__, 'destinations'),
        id=pulumi.get(__ret__, 'id'),
        securable=pulumi.get(__ret__, 'securable'))
def get_rfa_access_request_destinations_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRfaAccessRequestDestinationsResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get the Request for Access (RFA) access request destinations for a specific securable object.

    ## Example Usage

    Referring to RFA access request destinations by securable type and full name:
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getRfaAccessRequestDestinations:getRfaAccessRequestDestinations', __args__, opts=opts, typ=GetRfaAccessRequestDestinationsResult)
    return __ret__.apply(lambda __response__: GetRfaAccessRequestDestinationsResult(
        are_any_destinations_hidden=pulumi.get(__response__, 'are_any_destinations_hidden'),
        destinations=pulumi.get(__response__, 'destinations'),
        id=pulumi.get(__response__, 'id'),
        securable=pulumi.get(__response__, 'securable')))
